data(airquality)
keep=!(is.na(airquality$Ozone) | is.na(airquality$Temp) | is.na(airquality$Wind) | is.na(airquality$Solar.R))
airqual=data.frame(Ozone=airquality$Ozone[keep],Solar.R=airquality$Solar.R[keep],
                   Wind=airquality$Wind[keep],Temp=airquality$Temp[keep])

testqual=data.frame(Wind=seq(min(airqual$Wind),max(airqual$Wind),length=100),Temp=seq(min(airqual$Temp),max(airqual$Temp),length=100))

postscript("ozone.eps",onefile=F,paper="special",width=11.69,height=8.27)
par(mai=c(0.8,0.8,0.4,0.1))
plot(airqual$Wind,airqual$Ozone,xlab="Wind",ylab="Ozone")
dev.off()

erreurPoly=rep(0,7)
erreurMLP=rep(0,7)
for(i in seq(1,7)) {
  load(paste("mlp-ozone.",i,".robj",sep=""))
  model=lm(as.formula(paste("Ozone ~ ", paste(paste("I(Wind^", 1:i, ")",sep=""), collapse= "+"))),data=airqual)
  postscript(paste("ozone-",i,".eps",sep=""),onefile=F,paper="special",width=11.69,height=8.27)
  par(mai=c(0.8,0.8,0.4,0.1))
  plot(airqual$Wind,airqual$Ozone,xlab="Wind",ylab="Ozone",main=paste("degr",i))
  lines(testqual$Wind,predict(model,testqual),col="red",lwd=2)
  erreurPoly[i]=sum((residuals(model))^2)/length(airqual$Wind)
  lines(testqual$Wind,predict(mlp,as.matrix(testqual$Wind)),col="blue",lwd=2)
  legend(16,170,c("donnes","pseudo linaire","PMC"),col=c("black","red","blue"),lty=c(0,1,1),pch=c(1,NA,NA))
  erreurMLP[i]=sum((residuals(mlp))^2)/length(airqual$Wind)
  dev.off()
}

postscript("ozone-error.eps",onefile=F,paper="special",width=11.69,height=8.27)
par(mai=c(0.8,0.8,0.1,0.1))
plot(erreurPoly,type="l",xlab="degr",ylab="Erreur rsiduelle moyenne",lwd=2,ylim=range(erreurMLP,erreurPoly),col="red")
lines(erreurMLP,lwd=2,col="blue")
legend(7,max(erreurMLP,erreurPoly),c("pseudo linaire","PMC"),col=c("red","blue"),lty=c(1,1),xjust=1)
dev.off()
